from typing import List
import ghidra.docking.settings
import ghidra.program.model.data
import ghidra.program.model.mem
import ghidra.util
import java.lang
import java.net
import java.util


class StructureDataType(ghidra.program.model.data.CompositeDataTypeImpl, ghidra.program.model.data.StructureInternal):
    """
    Basic implementation of the structure data type.
     NOTES: 
 
     Implementation is not thread safe when being modified.
     For a structure to treated as having a zero-length (see #isZeroLength()) it 
 
 
    """





    @overload
    def __init__(self, name: unicode, length: int):
        """
        Construct a new structure with the given name and length. The root category will be used.
        @param name the name of the new structure
        @param length the initial size of the structure in bytes. If 0 is specified the structure
                    will report its length as 1 and {@link #isNotYetDefined()} will return true.
        """
        ...

    @overload
    def __init__(self, path: ghidra.program.model.data.CategoryPath, name: unicode, length: int):
        """
        Construct a new structure with the given name and length within the specified categry path.
        @param path the category path indicating where this data type is located.
        @param name the name of the new structure
        @param length the initial size of the structure in bytes. If 0 is specified the structure
                    will report its length as 1 and {@link #isNotYetDefined()} will return true.
        """
        ...

    @overload
    def __init__(self, name: unicode, length: int, dtm: ghidra.program.model.data.DataTypeManager):
        """
        Construct a new structure with the given name, length and datatype manager which conveys data
         organization. The root category will be used.
        @param name the name of the new structure
        @param length the initial size of the structure in bytes. If 0 is specified the structure
                    will report its length as 1 and {@link #isNotYetDefined()} will return true.
        @param dtm the data type manager associated with this data type. This can be null. Also, the
                    data type manager may not yet contain this actual data type.
        """
        ...

    @overload
    def __init__(self, path: ghidra.program.model.data.CategoryPath, name: unicode, length: int, dtm: ghidra.program.model.data.DataTypeManager):
        """
        Construct a new structure with the given name, length and datatype manager within the
         specified categry path.
        @param path the category path indicating where this data type is located.
        @param name the name of the new structure
        @param length the initial size of the structure in bytes. If 0 is specified the structure
                    will report its length as 1 and {@link #isNotYetDefined()} will return true.
        @param dtm the data type manager associated with this data type. This can be null. Also, the
                    data type manager may not yet contain this actual data type.
        """
        ...

    @overload
    def __init__(self, path: ghidra.program.model.data.CategoryPath, name: unicode, length: int, universalID: ghidra.util.UniversalID, sourceArchive: ghidra.program.model.data.SourceArchive, lastChangeTime: long, lastChangeTimeInSourceArchive: long, dtm: ghidra.program.model.data.DataTypeManager):
        """
        Construct a new structure with the given name and length
        @param path the category path indicating where this data type is located.
        @param name the name of the new structure
        @param length the initial size of the structure in bytes. If 0 is specified the structure
                    will report its length as 1 and {@link #isNotYetDefined()} will return true.
        @param universalID the id for the data type
        @param sourceArchive the source archive for this data type
        @param lastChangeTime the last time this data type was changed
        @param lastChangeTimeInSourceArchive the last time this data type was changed in its source
                    archive.
        @param dtm the data type manager associated with this data type. This can be null. Also, the
                    data type manager may not yet contain this actual data type.
        """
        ...



    @overload
    def add(self, dataType: ghidra.program.model.data.DataType) -> ghidra.program.model.data.DataTypeComponent: ...

    @overload
    def add(self, dataType: ghidra.program.model.data.DataType, length: int) -> ghidra.program.model.data.DataTypeComponent: ...

    @overload
    def add(self, dataType: ghidra.program.model.data.DataType, fieldName: unicode, comment: unicode) -> ghidra.program.model.data.DataTypeComponent: ...

    @overload
    def add(self, dataType: ghidra.program.model.data.DataType, length: int, componentName: unicode, comment: unicode) -> ghidra.program.model.data.DataTypeComponent: ...

    def addBitField(self, baseDataType: ghidra.program.model.data.DataType, bitSize: int, componentName: unicode, comment: unicode) -> ghidra.program.model.data.DataTypeComponent: ...

    def addParent(self, dt: ghidra.program.model.data.DataType) -> None: ...

    def align(self, __a0: int) -> None: ...

    def clearAtOffset(self, offset: int) -> None: ...

    def clearComponent(self, ordinal: int) -> None: ...

    def clone(self, dtm: ghidra.program.model.data.DataTypeManager) -> ghidra.program.model.data.StructureDataType:
        """
        Create cloned structure for target dtm preserving source archive information. WARNING!
         cloning non-packed structures which contain bitfields can produce invalid results when
         switching endianess due to the differences in packing order.
        @param dtm target data type manager
        @return cloned structure
        """
        ...

    def copy(self, dtm: ghidra.program.model.data.DataTypeManager) -> ghidra.program.model.data.DataType:
        """
        Create copy of structure for target dtm (source archive information is discarded). 
         <p>
         WARNING! copying non-packed structures which contain bitfields can produce invalid results when
         switching endianess due to the differences in packing order.
        @param dtm target data type manager
        @return cloned structure
        """
        ...

    def dataTypeAlignmentChanged(self, dt: ghidra.program.model.data.DataType) -> None: ...

    def dataTypeDeleted(self, dt: ghidra.program.model.data.DataType) -> None: ...

    def dataTypeNameChanged(self, dt: ghidra.program.model.data.DataType, oldName: unicode) -> None: ...

    def dataTypeReplaced(self, oldDt: ghidra.program.model.data.DataType, replacementDt: ghidra.program.model.data.DataType) -> None: ...

    def dataTypeSizeChanged(self, dt: ghidra.program.model.data.DataType) -> None: ...

    @overload
    def delete(self, ordinal: int) -> None: ...

    @overload
    def delete(self, ordinals: java.util.Set) -> None: ...

    def deleteAll(self) -> None: ...

    def deleteAtOffset(self, offset: int) -> None: ...

    def dependsOn(self, dt: ghidra.program.model.data.DataType) -> bool: ...

    def encodeRepresentation(self, repr: unicode, buf: ghidra.program.model.mem.MemBuffer, settings: ghidra.docking.settings.Settings, length: int) -> List[int]: ...

    def encodeValue(self, value: object, buf: ghidra.program.model.mem.MemBuffer, settings: ghidra.docking.settings.Settings, length: int) -> List[int]: ...

    def equals(self, obj: object) -> bool: ...

    def getAlignment(self) -> int: ...

    @staticmethod
    def getAlignmentAndPackingString(__a0: ghidra.program.model.data.Composite) -> unicode: ...

    def getAlignmentType(self) -> ghidra.program.model.data.AlignmentType: ...

    def getCategoryPath(self) -> ghidra.program.model.data.CategoryPath: ...

    def getClass(self) -> java.lang.Class: ...

    def getComponent(self, ordinal: int) -> ghidra.program.model.data.DataTypeComponentImpl: ...

    def getComponentAt(self, __a0: int) -> ghidra.program.model.data.DataTypeComponent: ...

    def getComponentContaining(self, offset: int) -> ghidra.program.model.data.DataTypeComponent: ...

    def getComponents(self) -> List[ghidra.program.model.data.DataTypeComponent]: ...

    def getComponentsContaining(self, offset: int) -> List[ghidra.program.model.data.DataTypeComponent]: ...

    def getDataOrganization(self) -> ghidra.program.model.data.DataOrganization: ...

    def getDataTypeAt(self, offset: int) -> ghidra.program.model.data.DataTypeComponent: ...

    def getDataTypeManager(self) -> ghidra.program.model.data.DataTypeManager:
        """
        @see ghidra.program.model.data.DataType#getDataTypeManager()
        """
        ...

    def getDataTypePath(self) -> ghidra.program.model.data.DataTypePath: ...

    def getDefaultAbbreviatedLabelPrefix(self) -> unicode: ...

    @overload
    def getDefaultLabelPrefix(self) -> unicode: ...

    @overload
    def getDefaultLabelPrefix(self, buf: ghidra.program.model.mem.MemBuffer, settings: ghidra.docking.settings.Settings, len: int, options: ghidra.program.model.data.DataTypeDisplayOptions) -> unicode: ...

    def getDefaultOffcutLabelPrefix(self, buf: ghidra.program.model.mem.MemBuffer, settings: ghidra.docking.settings.Settings, len: int, options: ghidra.program.model.data.DataTypeDisplayOptions, offcutLength: int) -> unicode: ...

    def getDefaultSettings(self) -> ghidra.docking.settings.Settings: ...

    def getDefinedComponentAtOrAfterOffset(self, offset: int) -> ghidra.program.model.data.DataTypeComponent: ...

    def getDefinedComponents(self) -> List[ghidra.program.model.data.DataTypeComponent]: ...

    def getDescription(self) -> unicode: ...

    def getDisplayName(self) -> unicode: ...

    def getDocs(self) -> java.net.URL: ...

    def getExplicitMinimumAlignment(self) -> int: ...

    def getExplicitPackingValue(self) -> int: ...

    def getLastChangeTime(self) -> long: ...

    def getLastChangeTimeInSourceArchive(self) -> long: ...

    def getLength(self) -> int: ...

    @staticmethod
    def getMinAlignmentString(__a0: ghidra.program.model.data.Composite) -> unicode: ...

    def getMnemonic(self, settings: ghidra.docking.settings.Settings) -> unicode: ...

    def getName(self) -> unicode: ...

    def getNumComponents(self) -> int: ...

    def getNumDefinedComponents(self) -> int: ...

    @staticmethod
    def getPackingString(__a0: ghidra.program.model.data.Composite) -> unicode: ...

    def getPackingType(self) -> ghidra.program.model.data.PackingType: ...

    def getParents(self) -> java.util.Collection: ...

    def getPathName(self) -> unicode: ...

    def getRepresentation(self, buf: ghidra.program.model.mem.MemBuffer, settings: ghidra.docking.settings.Settings, length: int) -> unicode: ...

    def getSettingsDefinitions(self) -> List[ghidra.docking.settings.SettingsDefinition]: ...

    def getSourceArchive(self) -> ghidra.program.model.data.SourceArchive: ...

    def getStoredMinimumAlignment(self) -> int: ...

    def getStoredPackingValue(self) -> int: ...

    def getTypeDefSettingsDefinitions(self) -> List[ghidra.program.model.data.TypeDefSettingsDefinition]: ...

    def getUniversalID(self) -> ghidra.util.UniversalID: ...

    def getValue(self, buf: ghidra.program.model.mem.MemBuffer, settings: ghidra.docking.settings.Settings, length: int) -> object: ...

    def getValueClass(self, settings: ghidra.docking.settings.Settings) -> java.lang.Class: ...

    def growStructure(self, amount: int) -> None: ...

    def hasDefaultPacking(self) -> bool: ...

    def hasExplicitMinimumAlignment(self) -> bool: ...

    def hasExplicitPackingValue(self) -> bool: ...

    def hasLanguageDependantLength(self) -> bool: ...

    def hashCode(self) -> int: ...

    @overload
    def insert(self, ordinal: int, dataType: ghidra.program.model.data.DataType) -> ghidra.program.model.data.DataTypeComponent: ...

    @overload
    def insert(self, ordinal: int, dataType: ghidra.program.model.data.DataType, length: int) -> ghidra.program.model.data.DataTypeComponent: ...

    @overload
    def insert(self, ordinal: int, dataType: ghidra.program.model.data.DataType, length: int, componentName: unicode, comment: unicode) -> ghidra.program.model.data.DataTypeComponent: ...

    @overload
    def insertAtOffset(self, offset: int, dataType: ghidra.program.model.data.DataType, length: int) -> ghidra.program.model.data.DataTypeComponentImpl: ...

    @overload
    def insertAtOffset(self, offset: int, dataType: ghidra.program.model.data.DataType, length: int, componentName: unicode, comment: unicode) -> ghidra.program.model.data.DataTypeComponentImpl: ...

    def insertBitField(self, ordinal: int, byteWidth: int, bitOffset: int, baseDataType: ghidra.program.model.data.DataType, bitSize: int, componentName: unicode, comment: unicode) -> ghidra.program.model.data.DataTypeComponent: ...

    def insertBitFieldAt(self, byteOffset: int, byteWidth: int, bitOffset: int, baseDataType: ghidra.program.model.data.DataType, bitSize: int, componentName: unicode, comment: unicode) -> ghidra.program.model.data.DataTypeComponentImpl: ...

    def isDefaultAligned(self) -> bool: ...

    def isDeleted(self) -> bool: ...

    def isEncodable(self) -> bool: ...

    def isEquivalent(self, dataType: ghidra.program.model.data.DataType) -> bool: ...

    def isMachineAligned(self) -> bool: ...

    def isNotYetDefined(self) -> bool:
        """
        Determine if this composite should be treated as undefined.
         <p>
         A composite is considered undefined with a zero-length when it has 
         no components and packing is disabled.  A {@link DataTypeComponent} defined by an
         an datatype which is not-yet-defined (i.e., {@link DataType#isNotYetDefined()} is true) 
         will always have a size of 1.  If an empty composite should be treated as 
         fully specified, packing on the composite should be enabled to ensure that 
         a zero-length component is used should the occassion arise (e.g., empty structure 
         placed within union as a component).
        """
        ...

    def isPackingEnabled(self) -> bool: ...

    def isPartOf(self, dataTypeOfInterest: ghidra.program.model.data.DataType) -> bool: ...

    def isZeroLength(self) -> bool: ...

    def notify(self) -> None: ...

    def notifyAll(self) -> None: ...

    def pack(self, __a0: int) -> None: ...

    def removeParent(self, dt: ghidra.program.model.data.DataType) -> None: ...

    @overload
    def repack(self) -> None: ...

    @overload
    def repack(self, notify: bool) -> bool: ...

    @overload
    def replace(self, index: int, dataType: ghidra.program.model.data.DataType, length: int) -> ghidra.program.model.data.DataTypeComponent: ...

    @overload
    def replace(self, ordinal: int, dataType: ghidra.program.model.data.DataType, length: int, componentName: unicode, comment: unicode) -> ghidra.program.model.data.DataTypeComponent: ...

    def replaceAtOffset(self, offset: int, dataType: ghidra.program.model.data.DataType, length: int, name: unicode, comment: unicode) -> ghidra.program.model.data.DataTypeComponent: ...

    def replaceWith(self, dataType: ghidra.program.model.data.DataType) -> None:
        """
        Replaces the internal components of this structure with components of the given structure
         including packing and alignment settings.
        @param dataType the structure to get the component information from.
        @throws IllegalArgumentException if any of the component data types are not allowed to
                     replace a component in this composite data type. For example, suppose dt1
                     contains dt2. Therefore it is not valid to replace a dt2 component with dt1 since
                     this would cause a cyclic dependency.
        """
        ...

    def setCategoryPath(self, path: ghidra.program.model.data.CategoryPath) -> None: ...

    def setDescription(self, desc: unicode) -> None: ...

    def setExplicitMinimumAlignment(self, minimumAlignment: int) -> None: ...

    def setExplicitPackingValue(self, packingValue: int) -> None: ...

    def setLastChangeTime(self, lastChangeTime: long) -> None: ...

    def setLastChangeTimeInSourceArchive(self, lastChangeTimeInSourceArchive: long) -> None: ...

    def setName(self, name: unicode) -> None: ...

    def setNameAndCategory(self, path: ghidra.program.model.data.CategoryPath, name: unicode) -> None: ...

    def setPackingEnabled(self, enabled: bool) -> None: ...

    def setSourceArchive(self, archive: ghidra.program.model.data.SourceArchive) -> None: ...

    def setToDefaultAligned(self) -> None: ...

    def setToDefaultPacking(self) -> None: ...

    def setToMachineAligned(self) -> None: ...

    def setValue(self, buf: ghidra.program.model.mem.MemBuffer, settings: ghidra.docking.settings.Settings, length: int, value: object) -> None: ...

    def toString(self) -> unicode: ...

    @overload
    def wait(self) -> None: ...

    @overload
    def wait(self, __a0: long) -> None: ...

    @overload
    def wait(self, __a0: long, __a1: int) -> None: ...

    @property
    def alignment(self) -> int: ...

    @property
    def components(self) -> List[ghidra.program.model.data.DataTypeComponent]: ...

    @property
    def defaultLabelPrefix(self) -> unicode: ...

    @property
    def definedComponents(self) -> List[ghidra.program.model.data.DataTypeComponent]: ...

    @property
    def length(self) -> int: ...

    @property
    def numComponents(self) -> int: ...

    @property
    def numDefinedComponents(self) -> int: ...

    @property
    def zeroLength(self) -> bool: ...